@@ -2,19 +2,32 @@ use crate::{errors::HypergraphError, HyperedgeIndex, Hypergraph, SharedTrait, Ve
 
 use itertools::Itertools;
 
+/// Enumeration of the different types of connection.
+/// Only used as a guard argument for the `get_connections` method.
+pub(crate) enum Connection<Index = VertexIndex> {
+    In(Index),
+    Out(Index),
+    InAndOut(Index, Index),
+}
+
 impl<V, HE> Hypergraph<V, HE>
 where
     V: SharedTrait,
     HE: SharedTrait,
 {
     /// Private helper function used internally.
+    /// Takes a connection as an enum and returns a vector of tuples of the
+    /// form (hyperedge index, connected vertex index) where connected vertex
+    /// index is an optional value - None for InAndOut connections.
     #[allow(clippy::type_complexity)]
     pub(crate) fn get_connections(
         &self,
-        from: VertexIndex,
-        to: Option<VertexIndex>,
+        connections: Connection,
     ) -> Result<Vec<(HyperedgeIndex, Option<VertexIndex>)>, HypergraphError<V, HE>> {
-        let internal_index = self.get_internal_vertex(from)?;
+        let internal_index = self.get_internal_vertex(match connections {
+            Connection::In(vertex_index) | Connection::Out(vertex_index) => vertex_index,
+            Connection::InAndOut(vertex_index, _) => vertex_index,
+        })?;
 
         let (_, hyperedges_index_set) = self
             .vertices
@@ -40,8 +53,27 @@ where
                 vertices.iter().tuple_windows::<(_, _)>().fold(
                     acc,
                     |index_acc, (window_from, window_to)| {
-                        match to {
-                            Some(to) => {
+                        match connections {
+                            Connection::In(from) => {
+                                // Inject the index of the hyperedge and the
+                                // vertex index if the current window is a
+                                // match.
+                                if *window_from == from {
+                                    return index_acc
+                                        .into_iter()
+                                        .chain(vec![(hyperedge_index, Some(*window_to))])
+                                        .collect_vec();
+                                }
+                            }
+                            Connection::Out(to) => {
+                                if *window_to == to {
+                                    return index_acc
+                                        .into_iter()
+                                        .chain(vec![(hyperedge_index, Some(*window_from))])
+                                        .collect_vec();
+                                }
+                            }
+                            Connection::InAndOut(from, to) => {
                                 // Inject only the index of the hyperedge
                                 // if the current window is a match.
                                 if *window_from == from && *window_to == to {
@@ -51,16 +83,6 @@ where
                                         .collect_vec();
                                 }
                             }
-                            None => {
-                                // Inject the index of the hyperedge and the
-                                // if the current window is a match.
-                                if *window_from == from {
-                                    return index_acc
-                                        .into_iter()
-                                        .chain(vec![(hyperedge_index, Some(*window_to))])
-                                        .collect_vec();
-                                }
-                            }
                         }
 
                         index_acc
